body {
    font-family: "PT Sans", sans-serif;
    margin: 0;
    padding: 0;
    border: 0;
    background-color: #ddd;
}

div {
    margin: 0;
    padding: 0;
    border: 0;
}

div.ontap {
    width: 100%;
    height: 25px;
    background: #E8E9DE url("/static/bg-introduction.gif") 100% 100% no-repeat;
    text-align: center;
    font-weight: bold;
    font-size: 17px;
    z-index: 1;
    border-bottom: 1px solid #555;
}

div.body-container {
    position: absolute;
    width: 900px;
    margin: 0 0 0 -450px;
    top: 0;
    bottom: 0;
    left: 50%;
    border-style: solid;
    border-color: #555;
    border-width: 0 1px;
    background-color: white;
    -webkit-box-shadow: 2px 2px 5px #666666;
    -moz-box-shadow: 2px 2px 5px #666666;
    box-shadow: 2px 2px 5px #666666;
}

div.beer-img-container {
    width: 140px;
    position: absolute;
    left: 0;
    margin: 0;
    padding: 0;
    border: 0;
}

body.has-active div.beer-img-container {
    border-right: 1px solid #555;
}

div.beer-img-container .beerimg {
    height: 140px;
    width: 140px;
    margin: -1px 0 0 0;
    padding: 0;
    border: 0;
    background-repeat: no-repeat;
    background-position: center center;
    border-top: 1px solid #555;
    border-bottom: 1px solid #555;
    cursor: pointer;
}

body.has-active div.beer-img-container .beerimg:hover {
    background-color: #ffb;
}

body.has-active div.beer-img-container .beerimg {
    opacity: 0.3;
}

body.has-active div.beer-img-container .beerimg.active {
    background-color: #ff9;
    opacity: 1.0;
}

div.tap-container {
    position: absolute;
    left: 140px;
    right: 0;
}

div.tap {
    width: 100%;
    height: 100%;
    position: relative;
    height: 140px;
    margin: 0;
    padding: 0;
    border-bottom: 1px solid #555;
    cursor: pointer;
}

div.tap.inactive {
    display: none;
}

div.tap.active {
    border: 0;
}

div.tap .name, div.tap .style, div.tap .brewery, div.tap .location, div.tap .abv {
    position: absolute;
    left: 120px;
    right: 0;
    text-align: center;
}

div.tap .breweryimg {
    position: absolute;
    top: 20px;
    left: 0;
    width: 100px;
    height: 100px;
}

div.tap .name {
    top: 15px;
    font-size: 20px;
    white-space: nowrap;
    font-weight: bold;
}

div.tap .style {
    top: 37px;
    font-size: 16px;
}

div.tap .brewery {
    top: 65px;
    font-size: 12px;
}

div.tap .location {
    top: 80px;
    font-size: 12px;
}

div.tap .abv {
    bottom: 10px;
    font-size: 22px;
    top: 100px;
}

div.tap .description, div.tap .brewerydescription, div.tap .checkin-link-container {
    display: none;
}

div.tap.active {
}

div.tap.active .name, div.tap.active .style, div.tap.active .brewery, div.tap.active .location, div.tap.active .abv {
    position: absolute;
    left: 0;
    right: 0;
    text-align: center;
}

div.tap.active .name {
    font-size: 24px;
}

div.tap.active .style {
    top: 44px;
}

div.tap.active .abv {
    top: 60px;
    font-size: 16px;
}

div.tap.active .description {
    position: absolute;
    top: 88px;
    height: 160px;
    left: 50px;
    right: 50px;
    display: block;
    overflow: hidden;
    text-align: justify;
    font-size: 12px;
}

div.tap.active .breweryimg {
    top: 265px;
    left: inherit;
    right: 10px;
}

div.tap.active .brewery {
    top: 285px;
    font-size: 20px;
    font-weight: bold;
}

div.tap.active .location {
    top: 309px;
    font-size: 16px;
}

div.tap.active .checkin-link-container {
    display: block;
    position: absolute;
    top: 349px;
    left: 0;
    right: 0;
    text-align: center;
}

div.tap.active .checkin-link {
    background-color: #fc0;
    padding: 8px 16px;
    cursor: pointer;
    font-family: "ProximaNova", "Helvetica Neue", "Helvetica", sans-serif;
    font-weight: bold;
    -webkit-border-radius: 8;
    -moz-border-radius: 8;
    border-radius: 8px;
    -webkit-box-shadow: 2px 2px 5px #666;
    -moz-box-shadow: 2px 2px 5px #666;
    box-shadow: 2px 2px 5px #666;
    background-image: -webkit-linear-gradient(top, #fc0, #eb0);
    background-image: -moz-linear-gradient(top, #fc0, #eb0);
    background-image: -ms-linear-gradient(top, #fc0, #eb0);
    background-image: -o-linear-gradient(top, #fc0, #eb0);
    background-image: linear-gradient(to bottom, #fc0, #eb0);
    color: black;
    text-decoration: none;
}

div.tap.active .checkin-link:hover {
}

div.tap-id {
    display: none;
}

img#pbu-image {
    position: absolute;
    bottom: 5px;
    right: 5px;
}